@@ -19,8 +19,6 @@
 package org.apache.skywalking.oap.meter.analyzer.dsl;
 
 import com.google.common.collect.ImmutableMap;
-import java.util.HashMap;
-import java.util.Map;
 import org.apache.skywalking.oap.meter.analyzer.Analyzer;
 import org.apache.skywalking.oap.server.core.analysis.IDManager;
 import org.apache.skywalking.oap.server.core.analysis.StreamDefinition;
@@ -36,25 +34,28 @@ import org.apache.skywalking.oap.server.core.config.NamingControl;
 import org.apache.skywalking.oap.server.core.config.group.EndpointNameGrouping;
 import org.apache.skywalking.oap.server.core.storage.StorageException;
 import org.apache.skywalking.oap.server.library.module.ModuleManager;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.Mock;
 import org.mockito.Mockito;
-import org.mockito.junit.MockitoJUnitRunner;
+import org.mockito.junit.jupiter.MockitoExtension;
 import org.powermock.reflect.Whitebox;
 
+import java.util.HashMap;
+import java.util.Map;
+
 import static com.google.common.collect.ImmutableMap.of;
-import static org.hamcrest.core.Is.is;
+import static org.assertj.core.api.AssertionsForClassTypes.assertThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.spy;
 
-@RunWith(MockitoJUnitRunner.Silent.class)
+@ExtendWith(MockitoExtension.class)
 public class AnalyzerTest {
 
     @Mock
@@ -62,7 +63,7 @@ public class AnalyzerTest {
     private MeterSystem meterSystem;
     private Analyzer analyzer;
 
-    @Before
+    @BeforeEach
     public void setup() throws StorageException {
         meterSystem = spy(new MeterSystem(moduleManager));
         Whitebox.setInternalState(MetricsStreamProcessor.class, "PROCESSOR",
@@ -72,13 +73,13 @@ public class AnalyzerTest {
 
     }
 
-    @BeforeClass
+    @BeforeAll
     public static void init() {
         MeterEntity.setNamingControl(
             new NamingControl(512, 512, 512, new EndpointNameGrouping()));
     }
 
-    @AfterClass
+    @AfterAll
     public static void tearDown() {
         MeterEntity.setNamingControl(null);
     }
@@ -117,14 +118,14 @@ public class AnalyzerTest {
         AvgFunction t3Cn = actValues.get(IDManager.ServiceInstanceID.buildId(
             IDManager.ServiceID.buildId("t3", true), "cn"));
 
-        Assert.assertEquals(50L, t1.getSummation(), 0.0);
-        Assert.assertEquals(1L, t1.getCount(), 0.0);
+        assertEquals(50L, t1.getSummation(), 0.0);
+        assertEquals(1L, t1.getCount(), 0.0);
 
-        Assert.assertEquals(150L, t1Us.getSummation(), 0.0);
-        Assert.assertEquals(1L, t1Us.getCount(), 0.0);
+        assertEquals(150L, t1Us.getSummation(), 0.0);
+        assertEquals(1L, t1Us.getCount(), 0.0);
 
-        Assert.assertEquals(54L, t3Cn.getSummation(), 0.0);
-        Assert.assertEquals(1L, t3Cn.getCount(), 0.0);
+        assertEquals(54L, t3Cn.getSummation(), 0.0);
+        assertEquals(1L, t3Cn.getCount(), 0.0);
     }
 
     @Test
@@ -162,18 +163,18 @@ public class AnalyzerTest {
         AvgLabeledFunction t3Cn = actValues.get(IDManager.ServiceInstanceID.buildId(
             IDManager.ServiceID.buildId("t3", true), "cn"));
 
-        Assert.assertEquals(50L, t1.getSummation().get(""), 0.0);
-        Assert.assertEquals(1L, t1.getCount().get(""), 0.0);
+        assertEquals(50L, t1.getSummation().get(""), 0.0);
+        assertEquals(1L, t1.getCount().get(""), 0.0);
 
-        Assert.assertEquals(50L, t1Us.getSummation().get(""), 0.0);
-        Assert.assertEquals(100L, t1Us.getSummation().get("10.0.0.1"), 0.0);
-        Assert.assertEquals(1L, t1Us.getCount().get(""), 0.0);
-        Assert.assertEquals(1L, t1Us.getCount().get("10.0.0.1"), 0.0);
+        assertEquals(50L, t1Us.getSummation().get(""), 0.0);
+        assertEquals(100L, t1Us.getSummation().get("10.0.0.1"), 0.0);
+        assertEquals(1L, t1Us.getCount().get(""), 0.0);
+        assertEquals(1L, t1Us.getCount().get("10.0.0.1"), 0.0);
 
-        Assert.assertEquals(51L, t3Cn.getSummation().get(""), 0.0);
-        Assert.assertEquals(3L, t3Cn.getSummation().get("10.0.0.1"), 0.0);
-        Assert.assertEquals(1L, t3Cn.getCount().get(""), 0.0);
-        Assert.assertEquals(1L, t3Cn.getCount().get("10.0.0.1"), 0.0);
+        assertEquals(51L, t3Cn.getSummation().get(""), 0.0);
+        assertEquals(3L, t3Cn.getSummation().get("10.0.0.1"), 0.0);
+        assertEquals(1L, t3Cn.getCount().get(""), 0.0);
+        assertEquals(1L, t3Cn.getCount().get("10.0.0.1"), 0.0);
     }
 
     @Test
@@ -217,7 +218,7 @@ public class AnalyzerTest {
         }).when(meterSystem).doStreamingCalculation(any());
 
         analyzer.analyse(input);
-        Assert.assertEquals(2, actValues.size());
+        assertEquals(2, actValues.size());
         String expServiceId = IDManager.ServiceID.buildId("service1", true);
         IntList expRanks = new IntList(2) {
             {
@@ -226,18 +227,18 @@ public class AnalyzerTest {
             }
         };
         actValues.forEach((key, actValue) -> {
-            Assert.assertEquals(expServiceId, actValue.getEntityId());
-            Assert.assertThat(expRanks, is(actValue.getRanks()));
+            assertEquals(expServiceId, actValue.getEntityId());
+            assertThat(expRanks).isEqualTo(actValue.getRanks());
 
         });
         AvgHistogramPercentileFunction instance1 = actValues.get("instance1");
         AvgHistogramPercentileFunction instance2 = actValues.get("instance2");
-        Assert.assertEquals(100L, instance1.getSummation().get("instance1:25"), 0.0);
-        Assert.assertEquals(300L, instance1.getSummation().get("instance1:1250"), 0.0);
-        Assert.assertEquals(1L, instance1.getCount().get("instance1:25"), 0.0);
-        Assert.assertEquals(1L, instance1.getCount().get("instance1:1250"), 0.0);
+        assertEquals(100L, instance1.getSummation().get("instance1:25"), 0.0);
+        assertEquals(300L, instance1.getSummation().get("instance1:1250"), 0.0);
+        assertEquals(1L, instance1.getCount().get("instance1:25"), 0.0);
+        assertEquals(1L, instance1.getCount().get("instance1:1250"), 0.0);
 
-        Assert.assertEquals(122L, instance2.getSummation().get("instance2:750"), 0.0);
-        Assert.assertEquals(1L, instance2.getCount().get("instance2:750"), 0.0);
+        assertEquals(122L, instance2.getSummation().get("instance2:750"), 0.0);
+        assertEquals(1L, instance2.getCount().get("instance2:750"), 0.0);
     }
 }
