@@ -24,20 +24,20 @@ import org.apache.skywalking.oap.server.configuration.api.ConfigurationModule;
 import org.apache.skywalking.oap.server.core.CoreModule;
 import org.apache.skywalking.oap.server.core.alarm.AlarmModule;
 import org.apache.skywalking.oap.server.library.module.ModuleProvider;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.powermock.reflect.Whitebox;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 
 public class AlarmModuleProviderTest {
 
     private AlarmModuleProvider moduleProvider;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         ServiceLoader<ModuleProvider> serviceLoader = ServiceLoader.load(ModuleProvider.class);
         Iterator<ModuleProvider> providerIterator = serviceLoader.iterator();
@@ -78,4 +78,4 @@ public class AlarmModuleProviderTest {
             ConfigurationModule.NAME
         }, modules);
     }
-}
\ No newline at end of file
+}
