@@ -19,11 +19,6 @@
 package org.apache.skywalking.oap.server.core.alarm.provider;
 
 import com.google.common.collect.Lists;
-import java.util.HashMap;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Map;
-import java.util.Objects;
 import lombok.Getter;
 import lombok.Setter;
 import org.apache.skywalking.oap.server.core.Const;
@@ -37,13 +32,20 @@ import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
 import org.apache.skywalking.oap.server.core.analysis.metrics.MultiIntValuesHolder;
 import org.apache.skywalking.oap.server.core.remote.grpc.proto.RemoteData;
 import org.apache.skywalking.oap.server.core.source.DefaultScopeDefine;
+import org.apache.skywalking.oap.server.core.storage.StorageID;
 import org.joda.time.LocalDateTime;
 import org.joda.time.format.DateTimeFormat;
 import org.joda.time.format.DateTimeFormatter;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.powermock.reflect.Whitebox;
 
+import java.util.HashMap;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+
 /**
  * Running rule is the core of how does alarm work.
  * <p>
@@ -76,9 +78,9 @@ public class RunningRuleTest {
         int period = Whitebox.getInternalState(window, "period");
         LinkedList<Metrics> metricsBuffer = Whitebox.getInternalState(window, "values");
 
-        Assert.assertTrue(startTime.equals(endTime));
-        Assert.assertEquals(15, period);
-        Assert.assertEquals(15, metricsBuffer.size());
+        Assertions.assertTrue(startTime.equals(endTime));
+        Assertions.assertEquals(15, period);
+        Assertions.assertEquals(15, metricsBuffer.size());
     }
 
     @Test
@@ -106,13 +108,13 @@ public class RunningRuleTest {
 
         // check at 201808301440
         List<AlarmMessage> alarmMessages = runningRule.check();
-        Assert.assertEquals(0, alarmMessages.size());
+        Assertions.assertEquals(0, alarmMessages.size());
 
         runningRule.in(getMetaInAlarm(123), getMetrics(timeInPeriod3, 74));
 
         // check at 201808301440
         alarmMessages = runningRule.check();
-        Assert.assertEquals(1, alarmMessages.size());
+        Assertions.assertEquals(1, alarmMessages.size());
     }
 
     @Test
@@ -140,14 +142,14 @@ public class RunningRuleTest {
 
         // check at 201808301440
         List<AlarmMessage> alarmMessages = runningRule.check();
-        Assert.assertEquals(0, alarmMessages.size());
+        Assertions.assertEquals(0, alarmMessages.size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
 
         runningRule.in(getMetaInAlarm(123), getMultipleValueMetrics(timeInPeriod3, 74, 60, 40, 40, 40));
 
         // check at 201808301440
         alarmMessages = runningRule.check();
-        Assert.assertEquals(1, alarmMessages.size());
+        Assertions.assertEquals(1, alarmMessages.size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
     }
 
@@ -205,13 +207,13 @@ public class RunningRuleTest {
         runningRule.in(getMetaInAlarm(123), getMetrics(timeInPeriod5, 95));
 
         // check at 201808301440
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301442"));
         // check at 201808301441
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301443"));
         // check at 201808301442
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
     }
 
     @Test
@@ -236,22 +238,22 @@ public class RunningRuleTest {
         runningRule.in(getMetaInAlarm(123), getMetrics(timeInPeriod2, 71));
 
         // check at 201808301440
-        Assert.assertEquals(0, runningRule.check().size()); //check matches, no alarm
+        Assertions.assertEquals(0, runningRule.check().size()); //check matches, no alarm
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
 
         runningRule.in(getMetaInAlarm(123), getMetrics(timeInPeriod3, 74));
 
         // check at 201808301440
-        Assert.assertEquals(1, runningRule.check().size()); //alarm
+        Assertions.assertEquals(1, runningRule.check().size()); //alarm
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
 
         // check at 201808301442
-        Assert.assertEquals(0, runningRule.check().size()); //silence, no alarm
-        Assert.assertEquals(0, runningRule.check().size()); //silence, no alarm
-        Assert.assertNotEquals(0, runningRule.check().size()); //alarm
-        Assert.assertEquals(0, runningRule.check().size()); //silence, no alarm
-        Assert.assertEquals(0, runningRule.check().size()); //silence, no alarm
-        Assert.assertNotEquals(0, runningRule.check().size()); //alarm
+        Assertions.assertEquals(0, runningRule.check().size()); //silence, no alarm
+        Assertions.assertEquals(0, runningRule.check().size()); //silence, no alarm
+        Assertions.assertNotEquals(0, runningRule.check().size()); //alarm
+        Assertions.assertEquals(0, runningRule.check().size()); //silence, no alarm
+        Assertions.assertEquals(0, runningRule.check().size()); //silence, no alarm
+        Assertions.assertNotEquals(0, runningRule.check().size()); //alarm
     }
 
     @Test
@@ -279,13 +281,13 @@ public class RunningRuleTest {
         runningRule.in(getMetaInAlarm(123), getMetrics(timeInPeriod3, 74));
 
         // check at 201808301440
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
         // check at 201808301441
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301442"));
         // check at 201808301442
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
     }
 
     @Test
@@ -314,13 +316,13 @@ public class RunningRuleTest {
         runningRule.in(getMetaInAlarm(223), getMetrics(timeInPeriod3, 74));
 
         // check at 201808301440
-        Assert.assertEquals(1, runningRule.check().size());
+        Assertions.assertEquals(1, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
         // check at 201808301441
-        Assert.assertEquals(1, runningRule.check().size());
+        Assertions.assertEquals(1, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301446"));
         // check at 201808301442
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
     }
 
     @Test
@@ -349,13 +351,13 @@ public class RunningRuleTest {
         runningRule.in(getMetaInAlarm(223), getMetrics(timeInPeriod3, 74));
 
         // check at 201808301440
-        Assert.assertEquals(1, runningRule.check().size());
+        Assertions.assertEquals(1, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
         // check at 201808301441
-        Assert.assertEquals(1, runningRule.check().size());
+        Assertions.assertEquals(1, runningRule.check().size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301446"));
         // check at 201808301442
-        Assert.assertEquals(0, runningRule.check().size());
+        Assertions.assertEquals(0, runningRule.check().size());
     }
 
     private MetaInAlarm getMetaInAlarm(int id) {
@@ -429,7 +431,7 @@ public class RunningRuleTest {
         private int value;
 
         @Override
-        protected String id0() {
+        protected StorageID id0() {
             return null;
         }
 
@@ -486,7 +488,7 @@ public class RunningRuleTest {
         }
 
         @Override
-        protected String id0() {
+        protected StorageID id0() {
             return null;
         }
 
@@ -538,7 +540,7 @@ public class RunningRuleTest {
         private DataTable value;
 
         @Override
-        protected String id0() {
+        protected StorageID id0() {
             return null;
         }
 
@@ -600,14 +602,14 @@ public class RunningRuleTest {
         runningRule.in(getMetaInAlarm(123), getLabeledValueMetrics(timeInPeriod2, "75,15|95,12"));
 
         List<AlarmMessage> alarmMessages = runningRule.check();
-        Assert.assertEquals(0, alarmMessages.size());
+        Assertions.assertEquals(0, alarmMessages.size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
 
         runningRule.in(getMetaInAlarm(123), getLabeledValueMetrics(timeInPeriod3, "90,1|99,20"));
 
         // check at 201808301440
         alarmMessages = runningRule.check();
-        Assert.assertEquals(1, alarmMessages.size());
+        Assertions.assertEquals(1, alarmMessages.size());
         runningRule.moveTo(TIME_BUCKET_FORMATTER.parseLocalDateTime("201808301441"));
     }
 }
