@@ -19,16 +19,15 @@
 package org.apache.skywalking.oap.server.core.analysis.worker;
 
 import java.util.List;
-import java.util.Properties;
 import lombok.extern.slf4j.Slf4j;
-import org.apache.skywalking.oap.server.library.datacarrier.DataCarrier;
-import org.apache.skywalking.oap.server.library.datacarrier.consumer.BulkConsumePool;
-import org.apache.skywalking.oap.server.library.datacarrier.consumer.ConsumerPoolFactory;
-import org.apache.skywalking.oap.server.library.datacarrier.consumer.IConsumer;
 import org.apache.skywalking.oap.server.core.UnexpectedException;
 import org.apache.skywalking.oap.server.core.analysis.data.MergableBufferedData;
 import org.apache.skywalking.oap.server.core.analysis.metrics.Metrics;
 import org.apache.skywalking.oap.server.core.worker.AbstractWorker;
+import org.apache.skywalking.oap.server.library.datacarrier.DataCarrier;
+import org.apache.skywalking.oap.server.library.datacarrier.consumer.BulkConsumePool;
+import org.apache.skywalking.oap.server.library.datacarrier.consumer.ConsumerPoolFactory;
+import org.apache.skywalking.oap.server.library.datacarrier.consumer.IConsumer;
 import org.apache.skywalking.oap.server.library.module.ModuleDefineHolder;
 import org.apache.skywalking.oap.server.telemetry.TelemetryModule;
 import org.apache.skywalking.oap.server.telemetry.api.CounterMetrics;
@@ -119,9 +118,6 @@ public class MetricsAggregateWorker extends AbstractWorker<Metrics> {
         if (currentTime - lastSendTime > l1FlushPeriod) {
             mergeDataCache.read().forEach(
                 data -> {
-                    if (log.isDebugEnabled()) {
-                        log.debug(data.toString());
-                    }
                     nextWorker.in(data);
                 }
             );
@@ -130,10 +126,6 @@ public class MetricsAggregateWorker extends AbstractWorker<Metrics> {
     }
 
     private class AggregatorConsumer implements IConsumer<Metrics> {
-        @Override
-        public void init(final Properties properties) {
-        }
-
         @Override
         public void consume(List<Metrics> data) {
             MetricsAggregateWorker.this.onWork(data);
@@ -144,10 +136,6 @@ public class MetricsAggregateWorker extends AbstractWorker<Metrics> {
             log.error(t.getMessage(), t);
         }
 
-        @Override
-        public void onExit() {
-        }
-
         @Override
         public void nothingToConsume() {
             flush();
