@@ -20,11 +20,11 @@ package org.apache.skywalking.oap.server.core.profiling.trace;
 
 import lombok.Getter;
 import lombok.Setter;
-import org.apache.skywalking.oap.server.core.Const;
 import org.apache.skywalking.oap.server.core.analysis.Stream;
 import org.apache.skywalking.oap.server.core.analysis.record.Record;
 import org.apache.skywalking.oap.server.core.analysis.worker.RecordStreamProcessor;
 import org.apache.skywalking.oap.server.core.source.ScopeDeclaration;
+import org.apache.skywalking.oap.server.core.storage.StorageID;
 import org.apache.skywalking.oap.server.core.storage.annotation.BanyanDB;
 import org.apache.skywalking.oap.server.core.storage.annotation.Column;
 import org.apache.skywalking.oap.server.core.storage.type.Convert2Entity;
@@ -50,23 +50,27 @@ public class ProfileTaskLogRecord extends Record {
     public static final String OPERATION_TIME = "operation_time";
     public static final String TIMESTAMP = "timestamp";
 
-    @Column(columnName = TASK_ID)
+    @Column(name = TASK_ID)
     private String taskId;
-    @Column(columnName = INSTANCE_ID)
+    @Column(name = INSTANCE_ID)
     @BanyanDB.SeriesID(index = 0)
     private String instanceId;
-    @Column(columnName = OPERATION_TYPE, storageOnly = true)
+    @Column(name = OPERATION_TYPE, storageOnly = true)
     private int operationType;
-    @Column(columnName = OPERATION_TIME)
+    @Column(name = OPERATION_TIME)
     private long operationTime;
     @Getter
     @Setter
-    @Column(columnName = TIMESTAMP)
+    @Column(name = TIMESTAMP)
     private long timestamp;
 
     @Override
-    public String id() {
-        return getTaskId() + Const.ID_CONNECTOR + getInstanceId() + Const.ID_CONNECTOR + getOperationType() + Const.ID_CONNECTOR + getOperationTime();
+    public StorageID id() {
+        return new StorageID()
+            .append(TASK_ID, getTaskId())
+            .append(INSTANCE_ID, getInstanceId())
+            .append(OPERATION_TYPE, getOperationType())
+            .append(OPERATION_TIME, getOperationTime());
     }
 
     public static class Builder implements StorageBuilder<ProfileTaskLogRecord> {
