@@ -18,12 +18,13 @@
 
 package org.apache.skywalking.oap.server.core.query.type;
 
-import java.util.ArrayList;
-import java.util.List;
 import lombok.Getter;
 import lombok.Setter;
 import lombok.experimental.Accessors;
 
+import java.util.ArrayList;
+import java.util.List;
+
 @Setter
 @Getter
 @Accessors(chain = true)
@@ -34,4 +35,8 @@ public class Logs {
     public Logs() {
         this.logs = new ArrayList<>();
     }
+
+    public Logs(final List<Log> logs) {
+        this.logs = logs;
+    }
 }
