@@ -33,9 +33,9 @@ import org.apache.skywalking.oap.server.receiver.envoy.ServiceMetaInfoFactoryImp
 import org.apache.skywalking.oap.server.receiver.envoy.als.AccessLogAnalyzer;
 import org.apache.skywalking.oap.server.receiver.envoy.als.Role;
 import org.apache.skywalking.oap.server.receiver.envoy.als.ServiceMetaInfo;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.mock;
@@ -45,7 +45,7 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
 
     private MockK8SAnalysis analysis;
 
-    @Before
+    @BeforeEach
     public void setUp() {
         analysis = new MockK8SAnalysis();
         analysis.init(null, new EnvoyMetricReceiverConfig() {
@@ -63,7 +63,7 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
             JsonFormat.parser().merge(isr, requestBuilder);
             Role identify = analysis.identify(requestBuilder.getIdentifier(), Role.NONE);
 
-            Assert.assertEquals(Role.PROXY, identify);
+            Assertions.assertEquals(Role.PROXY, identify);
         }
     }
 
@@ -74,7 +74,7 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
             JsonFormat.parser().merge(isr, requestBuilder);
             Role identify = analysis.identify(requestBuilder.getIdentifier(), Role.NONE);
 
-            Assert.assertEquals(Role.SIDECAR, identify);
+            Assertions.assertEquals(Role.SIDECAR, identify);
         }
     }
 
@@ -86,17 +86,17 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
 
             AccessLogAnalyzer.Result result = this.analysis.analysis(AccessLogAnalyzer.Result.builder().build(), requestBuilder.getIdentifier(), requestBuilder.getHttpLogs().getLogEntry(0), Role.PROXY);
 
-            Assert.assertEquals(2, result.getMetrics().getHttpMetrics().getMetricsCount());
+            Assertions.assertEquals(2, result.getMetrics().getHttpMetrics().getMetricsCount());
 
             HTTPServiceMeshMetric incoming = result.getMetrics().getHttpMetrics().getMetrics(0);
-            Assert.assertEquals("UNKNOWN", incoming.getSourceServiceName());
-            Assert.assertEquals("ingress", incoming.getDestServiceName());
-            Assert.assertEquals(DetectPoint.server, incoming.getDetectPoint());
+            Assertions.assertEquals("UNKNOWN", incoming.getSourceServiceName());
+            Assertions.assertEquals("ingress", incoming.getDestServiceName());
+            Assertions.assertEquals(DetectPoint.server, incoming.getDetectPoint());
 
             HTTPServiceMeshMetric outgoing = result.getMetrics().getHttpMetrics().getMetrics(1);
-            Assert.assertEquals("ingress", outgoing.getSourceServiceName());
-            Assert.assertEquals("productpage", outgoing.getDestServiceName());
-            Assert.assertEquals(DetectPoint.client, outgoing.getDetectPoint());
+            Assertions.assertEquals("ingress", outgoing.getSourceServiceName());
+            Assertions.assertEquals("productpage", outgoing.getDestServiceName());
+            Assertions.assertEquals(DetectPoint.client, outgoing.getDetectPoint());
         }
     }
 
@@ -108,12 +108,12 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
 
             AccessLogAnalyzer.Result result = this.analysis.analysis(AccessLogAnalyzer.Result.builder().build(), requestBuilder.getIdentifier(), requestBuilder.getHttpLogs().getLogEntry(0), Role.SIDECAR);
 
-            Assert.assertEquals(1, result.getMetrics().getHttpMetrics().getMetricsCount());
+            Assertions.assertEquals(1, result.getMetrics().getHttpMetrics().getMetricsCount());
 
             HTTPServiceMeshMetric incoming = result.getMetrics().getHttpMetrics().getMetrics(0);
-            Assert.assertEquals("", incoming.getSourceServiceName());
-            Assert.assertEquals("productpage", incoming.getDestServiceName());
-            Assert.assertEquals(DetectPoint.server, incoming.getDetectPoint());
+            Assertions.assertEquals("", incoming.getSourceServiceName());
+            Assertions.assertEquals("productpage", incoming.getDestServiceName());
+            Assertions.assertEquals(DetectPoint.server, incoming.getDetectPoint());
         }
     }
 
@@ -125,12 +125,12 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
 
             AccessLogAnalyzer.Result result = this.analysis.analysis(AccessLogAnalyzer.Result.builder().build(), requestBuilder.getIdentifier(), requestBuilder.getHttpLogs().getLogEntry(0), Role.SIDECAR);
 
-            Assert.assertEquals(1, result.getMetrics().getHttpMetrics().getMetricsCount());
+            Assertions.assertEquals(1, result.getMetrics().getHttpMetrics().getMetricsCount());
 
             HTTPServiceMeshMetric incoming = result.getMetrics().getHttpMetrics().getMetrics(0);
-            Assert.assertEquals("productpage", incoming.getSourceServiceName());
-            Assert.assertEquals("review", incoming.getDestServiceName());
-            Assert.assertEquals(DetectPoint.server, incoming.getDetectPoint());
+            Assertions.assertEquals("productpage", incoming.getSourceServiceName());
+            Assertions.assertEquals("review", incoming.getDestServiceName());
+            Assertions.assertEquals(DetectPoint.server, incoming.getDetectPoint());
         }
     }
 
@@ -142,12 +142,12 @@ public class K8SALSServiceMeshHTTPAnalysisTest {
 
             AccessLogAnalyzer.Result result = this.analysis.analysis(AccessLogAnalyzer.Result.builder().build(), requestBuilder.getIdentifier(), requestBuilder.getHttpLogs().getLogEntry(0), Role.SIDECAR);
 
-            Assert.assertEquals(1, result.getMetrics().getHttpMetrics().getMetricsCount());
+            Assertions.assertEquals(1, result.getMetrics().getHttpMetrics().getMetricsCount());
 
             HTTPServiceMeshMetric incoming = result.getMetrics().getHttpMetrics().getMetrics(0);
-            Assert.assertEquals("productpage", incoming.getSourceServiceName());
-            Assert.assertEquals("detail", incoming.getDestServiceName());
-            Assert.assertEquals(DetectPoint.client, incoming.getDetectPoint());
+            Assertions.assertEquals("productpage", incoming.getSourceServiceName());
+            Assertions.assertEquals("detail", incoming.getDestServiceName());
+            Assertions.assertEquals(DetectPoint.client, incoming.getDetectPoint());
         }
     }
 
