@@ -19,17 +19,13 @@
 package org.apache.skywalking.oap.server.storage.plugin.banyandb.stream;
 
 import com.google.common.collect.ImmutableSet;
-import com.google.gson.Gson;
 import org.apache.skywalking.banyandb.v1.client.AbstractQuery;
 import org.apache.skywalking.banyandb.v1.client.RowEntity;
 import org.apache.skywalking.banyandb.v1.client.StreamQuery;
 import org.apache.skywalking.banyandb.v1.client.StreamQueryResponse;
-import org.apache.skywalking.oap.server.core.analysis.IDManager;
 import org.apache.skywalking.oap.server.core.profiling.ebpf.storage.EBPFProfilingTargetType;
 import org.apache.skywalking.oap.server.core.profiling.ebpf.storage.EBPFProfilingTaskRecord;
 import org.apache.skywalking.oap.server.core.profiling.ebpf.storage.EBPFProfilingTriggerType;
-import org.apache.skywalking.oap.server.core.query.type.EBPFProfilingTask;
-import org.apache.skywalking.oap.server.core.query.type.EBPFProfilingTaskExtension;
 import org.apache.skywalking.oap.server.core.storage.profiling.ebpf.IEBPFProfilingTaskDAO;
 import org.apache.skywalking.oap.server.library.util.CollectionUtils;
 import org.apache.skywalking.oap.server.library.util.StringUtil;
@@ -38,7 +34,6 @@ import org.apache.skywalking.oap.server.storage.plugin.banyandb.BanyanDBStorageC
 
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.Set;
 import java.util.stream.Collectors;
@@ -55,17 +50,17 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
             EBPFProfilingTaskRecord.TARGET_TYPE,
             EBPFProfilingTaskRecord.CREATE_TIME,
             EBPFProfilingTaskRecord.LAST_UPDATE_TIME,
-            EBPFProfilingTaskRecord.TIME_BUCKET);
-
-    private static final Gson GSON = new Gson();
+            EBPFProfilingTaskRecord.EXTENSION_CONFIG_JSON,
+            EBPFProfilingTaskRecord.CONTINUOUS_PROFILING_JSON);
 
     public BanyanDBEBPFProfilingTaskDAO(BanyanDBStorageClient client) {
         super(client);
     }
 
     @Override
-    public List<EBPFProfilingTask> queryTasksByServices(List<String> serviceIdList, long taskStartTime, long latestUpdateTime) throws IOException {
-        List<EBPFProfilingTask> tasks = new ArrayList<>();
+    public List<EBPFProfilingTaskRecord> queryTasksByServices(List<String> serviceIdList, EBPFProfilingTriggerType triggerType,
+                                                        long taskStartTime, long latestUpdateTime) throws IOException {
+        List<EBPFProfilingTaskRecord> tasks = new ArrayList<>();
         for (final String serviceId : serviceIdList) {
             StreamQueryResponse resp = query(EBPFProfilingTaskRecord.INDEX_NAME, TAGS,
                 new QueryBuilder<StreamQuery>() {
@@ -73,6 +68,9 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
                     protected void apply(StreamQuery query) {
                         query.and(eq(EBPFProfilingTaskRecord.SERVICE_ID, serviceId));
                         appendTimeQuery(this, query, taskStartTime, latestUpdateTime);
+                        if (triggerType != null) {
+                            query.and(eq(EBPFProfilingTaskRecord.TRIGGER_TYPE, triggerType.value()));
+                        }
                         query.setOrderBy(new AbstractQuery.OrderBy(EBPFProfilingTaskRecord.CREATE_TIME, AbstractQuery.Sort.DESC));
                     }
                 });
@@ -83,8 +81,9 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
     }
 
     @Override
-    public List<EBPFProfilingTask> queryTasksByTargets(String serviceId, String serviceInstanceId, List<EBPFProfilingTargetType> targetTypes, long taskStartTime, long latestUpdateTime) throws IOException {
-        List<EBPFProfilingTask> tasks = new ArrayList<>();
+    public List<EBPFProfilingTaskRecord> queryTasksByTargets(String serviceId, String serviceInstanceId, List<EBPFProfilingTargetType> targetTypes,
+                                                       EBPFProfilingTriggerType triggerType, long taskStartTime, long latestUpdateTime) throws IOException {
+        List<EBPFProfilingTaskRecord> tasks = new ArrayList<>();
         for (final EBPFProfilingTargetType targetType : targetTypes) {
             StreamQueryResponse resp = query(EBPFProfilingTaskRecord.INDEX_NAME, TAGS,
                 new QueryBuilder<StreamQuery>() {
@@ -96,6 +95,9 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
                         if (StringUtil.isNotEmpty(serviceInstanceId)) {
                             query.and(eq(EBPFProfilingTaskRecord.INSTANCE_ID, serviceInstanceId));
                         }
+                        if (CollectionUtils.isNotEmpty(targetTypes)) {
+                            query.and(eq(EBPFProfilingTaskRecord.TRIGGER_TYPE, triggerType.value()));
+                        }
                         query.and(eq(EBPFProfilingTaskRecord.TARGET_TYPE, targetType.value()));
                         appendTimeQuery(this, query, taskStartTime, latestUpdateTime);
                         query.setOrderBy(new AbstractQuery.OrderBy(EBPFProfilingTaskRecord.CREATE_TIME, AbstractQuery.Sort.DESC));
@@ -108,7 +110,7 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
     }
 
     @Override
-    public EBPFProfilingTask queryById(String id) throws IOException {
+    public List<EBPFProfilingTaskRecord> getTaskRecord(String id) throws IOException {
         StreamQueryResponse resp = query(EBPFProfilingTaskRecord.INDEX_NAME, TAGS,
             new QueryBuilder<StreamQuery>() {
                 @Override
@@ -116,16 +118,7 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
                     query.and(eq(EBPFProfilingTaskRecord.LOGICAL_ID, id));
                 }
             });
-        final List<EBPFProfilingTask> tasks = resp.getElements().stream().map(this::buildTask).collect(Collectors.toList());
-        if (CollectionUtils.isEmpty(tasks)) {
-            return null;
-        }
-
-        EBPFProfilingTask result = tasks.get(0);
-        for (int i = 1; i < tasks.size(); i++) {
-            result = result.combine(tasks.get(i));
-        }
-        return result;
+        return resp.getElements().stream().map(this::buildTask).collect(Collectors.toList());
     }
 
     private void appendTimeQuery(QueryBuilder<StreamQuery> builder, StreamQuery query, long taskStartTime, long latestUpdateTime) {
@@ -137,34 +130,10 @@ public class BanyanDBEBPFProfilingTaskDAO extends AbstractBanyanDBDAO implements
         }
     }
 
-    private EBPFProfilingTask buildTask(final RowEntity rowEntity) {
+    private EBPFProfilingTaskRecord buildTask(final RowEntity rowEntity) {
         final EBPFProfilingTaskRecord.Builder builder = new EBPFProfilingTaskRecord.Builder();
-        final EBPFProfilingTaskRecord record = builder.storage2Entity(new BanyanDBConverter.StorageToStream(
+        return builder.storage2Entity(new BanyanDBConverter.StorageToStream(
                 EBPFProfilingTaskRecord.INDEX_NAME,
                 rowEntity));
-
-        final EBPFProfilingTask task = new EBPFProfilingTask();
-        task.setTaskId(record.getLogicalId());
-        task.setServiceId(record.getServiceId());
-        task.setServiceName(IDManager.ServiceID.analysisId(record.getServiceId()).getName());
-        if (StringUtil.isNotEmpty(record.getProcessLabelsJson())) {
-            task.setProcessLabels(GSON.<List<String>>fromJson(record.getProcessLabelsJson(), ArrayList.class));
-        } else {
-            task.setProcessLabels(Collections.emptyList());
-        }
-        if (StringUtil.isNotEmpty(record.getInstanceId())) {
-            task.setServiceInstanceId(record.getInstanceId());
-            task.setServiceInstanceName(IDManager.ServiceInstanceID.analysisId(record.getInstanceId()).getName());
-        }
-        task.setTaskStartTime(record.getStartTime());
-        task.setTriggerType(EBPFProfilingTriggerType.valueOf(record.getTriggerType()));
-        task.setFixedTriggerDuration(record.getFixedTriggerDuration());
-        task.setTargetType(EBPFProfilingTargetType.valueOf(record.getTargetType()));
-        task.setCreateTime(record.getCreateTime());
-        task.setLastUpdateTime(record.getLastUpdateTime());
-        if (StringUtil.isNotEmpty(record.getExtensionConfigJson())) {
-            task.setExtensionConfig(GSON.fromJson(record.getExtensionConfigJson(), EBPFProfilingTaskExtension.class));
-        }
-        return task;
     }
 }
