@@ -32,7 +32,7 @@ const msg = {
   dashboards: "Dashboards",
   profiles: "Profiles",
   database: "Database",
-  mySQL: "MySQL",
+  mySQL: "MySQL/MariaDB",
   serviceName: "Service Name",
   technologies: "Technologies",
   generalServicePanel: "General Service Panel",
@@ -176,11 +176,16 @@ const msg = {
   toTheRight: "To The Right",
   legendValues: "Legend Values",
   minDuration: "Minimal Request Duration",
-  when4xx:
-    "Sample HTTP requests and responses with tracing when response code between 400 and 499",
-  when5xx:
-    "Sample HTTP requests and responses with tracing when response code between 500 and 599",
+  when4xx: "Sample HTTP requests and responses with tracing when response code between 400 and 499",
+  when5xx: "Sample HTTP requests and responses with tracing when response code between 500 and 599",
   taskTitle: "HTTP request and response collecting rules",
+  iframeWidgetTip: "Add a link to a widget",
+  iframeSrc: "Iframe Link",
+  generateLink: "Generate Link",
+  setDuration: "Lock Query Duration",
+  openFunction: "OpenFunction",
+  period: "Period",
+  windows: "Windows",
   seconds: "Seconds",
   hourTip: "Select Hour",
   minuteTip: "Select Minute",
@@ -199,7 +204,7 @@ const msg = {
   topology: "Topology",
   trace: "Trace",
   alarm: "Alerting",
-  auto: "Auto",
+  auto: "Auto Fresh",
   reload: "Reload",
   version: "Version",
   copy: "Copy",
@@ -315,10 +320,10 @@ const msg = {
   viewLogs: "View Logs",
   logsTagsTip: `Only tags defined in the core/default/searchableLogsTags are searchable.
   Check more details on the Configuration Vocabulary page`,
-  keywordsOfContentLogTips:
-    "Current storage of SkyWalking OAP server does not support this.",
+  keywordsOfContentLogTips: "Current storage of SkyWalking OAP server does not support this.",
   setEvent: "Set Event",
   viewAttributes: "View",
+  attributes: "Attributes",
   serviceEvents: "Service Events",
   select: "Select",
   eventID: "Event ID",
@@ -370,10 +375,35 @@ const msg = {
   addKeywordsOfContent: "Please input a keyword of content",
   addExcludingKeywordsOfContent: "Please input a keyword of excluding content",
   noticeTag: "Please press Enter after inputting a tag(key=value).",
-  conditionNotice:
-    "Notice: Please press Enter after inputting a key of content, exclude key of content(key=value).",
+  conditionNotice: "Notice: Please press Enter after inputting a key of content, exclude key of content(key=value).",
   language: "Language",
   gateway: "Gateway",
   virtualMQ: "Virtual MQ",
+  AWSCloud: "AWS Cloud",
+  AWSCloudEKS: "EKS",
+  AWSCloudS3: "S3",
+  AWSCloudDynamoDB: "DynamoDB",
+  AWSGateway: "AWS API Gateway",
+  APIGateway: "API Gateway",
+  redis: "Redis",
+  elasticsearch: "Elasticsearch",
+  mq: "MQ",
+  rabbitMQ: "RabbitMQ",
+  save: "Save",
+  editStrategy: "Edit Policies",
+  policyList: "Policy List",
+  targetTypes: "Target Type",
+  monitorType: "Monitor Type",
+  count: "Count",
+  threshold: "Threshold",
+  uriRegex: "URI Regex",
+  uriList: "URI List",
+  processes: "Processes",
+  monitorInstances: "Monitor Instances",
+  processDashboards: "Process Dashboards",
+  instanceDashboards: "Instance Dashboards",
+  detailLabel: "Detail Label",
+  summary: "Summary",
+  detail: "Detail",
 };
 export default msg;
