@@ -32,7 +32,7 @@ const msg = {
   dashboards: "仪表盘",
   profiles: "性能剖析",
   database: "数据库",
-  mySQL: "MySQL",
+  mySQL: "MySQL/MariaDB",
   serviceName: "服务名称",
   technologies: "技术",
   health: "健康",
@@ -176,6 +176,13 @@ const msg = {
   when4xx: "当响应代码介于400和499之间时，带有跟踪的HTTP请求和响应示例",
   when5xx: "当响应代码介于500和599之间时，带有跟踪的HTTP请求和响应示例",
   taskTitle: "HTTP请求和响应收集规则",
+  iframeWidgetTip: "添加widget的链接",
+  iframeSrc: "Iframe链接",
+  generateLink: "生成链接",
+  setDuration: "锁定查询持续时间",
+  openFunction: "OpenFunction",
+  period: "周期",
+  windows: "Windows",
   seconds: "秒",
   hourTip: "选择小时",
   minuteTip: "选择分钟",
@@ -194,7 +201,7 @@ const msg = {
   trace: "追踪",
   alarm: "告警",
   event: "事件",
-  auto: "自动",
+  auto: "自动更新",
   reload: "刷新",
   editmode: "编辑模式",
   version: "版本",
@@ -282,12 +289,9 @@ const msg = {
   chartType: "图表类型",
   currentDepth: "当前深度",
   defaultDepth: "默认深度",
-  traceTagsTip:
-    "只有core/default/searchableTracesTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
-  logTagsTip:
-    "只有core/default/searchableTracesTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
-  alarmTagsTip:
-    "只有core/default/searchableTracesTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
+  traceTagsTip: "只有core/default/searchableTracesTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
+  logTagsTip: "只有core/default/searchableTracesTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
+  alarmTagsTip: "只有core/default/searchableTracesTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
   tagsLink: "配置词汇页",
   addTag: "请添加标签",
   logCategory: "日志类别",
@@ -310,8 +314,7 @@ const msg = {
   contentType: "内容类型",
   content: "内容",
   viewLogs: "查看日志",
-  logsTagsTip:
-    "只有core/default/searchableLogsTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
+  logsTagsTip: "只有core/default/searchableLogsTags中定义的标记才可搜索。查看配置词汇表页面上的更多详细信息。",
   keywordsOfContentLogTips: "SkyWalking OAP服务器的当前存储不支持此操作",
   setEvent: "设置事件",
   viewAttributes: "查看",
@@ -368,10 +371,36 @@ const msg = {
   addKeywordsOfContent: "请输入一个内容关键词",
   addExcludingKeywordsOfContent: "请输入一个内容不包含的关键词",
   noticeTag: "请输入一个标签(key=value)之后回车",
-  conditionNotice:
-    "请输入一个内容关键词或者内容不包含的关键词(key=value)之后回车",
+  conditionNotice: "请输入一个内容关键词或者内容不包含的关键词(key=value)之后回车",
   language: "语言",
   gateway: "网关",
   virtualMQ: "虚拟消息队列",
+  AWSCloud: "AWS云服务",
+  AWSCloudEKS: "EKS",
+  AWSCloudS3: "S3",
+  AWSCloudDynamoDB: "DynamoDB",
+  AWSGateway: "AWS API Gateway",
+  APIGateway: "API Gateway",
+  redis: "Redis",
+  elasticsearch: "Elasticsearch",
+  mq: "消息队列",
+  rabbitMQ: "RabbitMQ",
+  save: "保存",
+  editStrategy: "编辑策略",
+  policyList: "策略列表",
+  targetTypes: "目标类型",
+  monitorType: "监视器类型",
+  count: "总数",
+  threshold: "阈值",
+  uriRegex: "URI规则",
+  uriList: "URI列表",
+  processes: "进程",
+  attributes: "属性",
+  monitorInstances: "监视实例",
+  processDashboards: "进程仪表板",
+  instanceDashboards: "实例仪表板",
+  detailLabel: "详细标签",
+  summary: "概括",
+  detail: "详细",
 };
 export default msg;
