@@ -21,18 +21,25 @@ export default [
     name: "Functions",
     meta: {
       title: "functions",
-      icon: "cloud_queue",
-      layer: "FAAS",
+      icon: "functions",
+      hasGroup: true,
     },
-    redirect: "/functions",
     children: [
       {
-        path: "/functions",
-        name: "Functions",
+        path: "/openFunction",
+        name: "OpenFunction",
+        meta: {
+          title: "openFunction",
+          layer: "FAAS",
+        },
       },
       {
-        path: "/functions/tab/:activeTabIndex",
-        name: "FunctionsActiveTabIndex",
+        path: "/openFunction/tab/:activeTabIndex",
+        name: "OpenFunctionActiveTabIndex",
+        meta: {
+          notShow: true,
+          layer: "FAAS",
+        },
       },
     ],
   },
