@@ -42,6 +42,22 @@ export default [
           layer: "APISIX",
         },
       },
+      {
+        path: "/aws-gateway",
+        name: "AWSGateway",
+        meta: {
+          title: "AWSGateway",
+          layer: "AWS_GATEWAY",
+        },
+      },
+      {
+        path: "/aws-gateway/tab/:activeTabIndex",
+        name: "GatewayActiveTabIndex",
+        meta: {
+          notShow: true,
+          layer: "AWS_GATEWAY",
+        },
+      },
     ],
   },
 ];
