@@ -23,6 +23,8 @@ import functions from "./functions";
 import browser from "./browser";
 import k8s from "./k8s";
 import gateway from "./gateway";
+import aws from "./aws";
+import mq from "./mq";
 
 export default [
   ...general,
@@ -30,8 +32,10 @@ export default [
   ...functions,
   ...k8s,
   ...infrastructure,
+  ...aws,
   ...browser,
   ...gateway,
   ...database,
+  ...mq,
   ...selfObservability,
 ];
