@@ -20,6 +20,8 @@ import Widget from "./Widget.vue";
 import Topology from "./Topology.vue";
 import Event from "./Event.vue";
 import TimeRange from "./TimeRange.vue";
+import ThirdPartyApp from "./ThirdPartyApp.vue";
+import ContinuousProfiling from "./ContinuousProfiling.vue";
 
 export default {
   Text,
@@ -27,4 +29,6 @@ export default {
   Topology,
   Event,
   TimeRange,
+  ThirdPartyApp,
+  ContinuousProfiling,
 };
