@@ -17,7 +17,9 @@
 
 import * as d3 from "d3";
 import d3tip from "d3-tip";
-import { Trace } from "@/types/trace";
+import type { Trace } from "@/types/trace";
+import dayjs from "dayjs";
+import icons from "@/assets/img/icons";
 
 export default class ListGraph {
   private barHeight = 48;
@@ -28,6 +30,7 @@ export default class ListGraph {
   private height = 0;
   private svg: any = null;
   private tip: any = null;
+  private prompt: any = null;
   private row: any[] = [];
   private data: any = [];
   private min = 0;
@@ -52,32 +55,33 @@ export default class ListGraph {
     this.tip = (d3tip as any)()
       .attr("class", "d3-tip")
       .offset([-8, 0])
-      .html((d: any) => {
+      .html((d: Recordable) => {
         return `
           <div class="mb-5">${d.data.label}</div>
-          ${
-            d.data.dur
-              ? '<div class="sm">SelfDuration: ' + d.data.dur + "ms</div>"
-              : ""
-          }
+          ${d.data.dur ? '<div class="sm">SelfDuration: ' + d.data.dur + "ms</div>" : ""}
           ${
             d.data.endTime - d.data.startTime
-              ? '<div class="sm">TotalDuration: ' +
-                (d.data.endTime - d.data.startTime) +
-                "ms</div>"
+              ? '<div class="sm">TotalDuration: ' + (d.data.endTime - d.data.startTime) + "ms</div>"
               : ""
           }
           `;
       });
+    this.prompt = (d3tip as any)()
+      .attr("class", "d3-tip")
+      .offset([-8, 0])
+      .html((d: any) => {
+        return `<div class="mb-5">${d.data.type}</div>`;
+      });
     this.svg.call(this.tip);
+    this.svg.call(this.prompt);
   }
-  diagonal(d: any) {
+  diagonal(d: Recordable) {
     return `M ${d.source.y} ${d.source.x + 5}
     L ${d.source.y} ${d.target.x - 30}
     L${d.target.y} ${d.target.x - 20}
     L${d.target.y} ${d.target.x - 5}`;
   }
-  init(data: any, row: any[], fixSpansSize: number) {
+  init(data: Recordable, row: Recordable[], fixSpansSize: number) {
     d3.select(".trace-xaxis").remove();
     this.row = row;
     this.data = data;
@@ -93,14 +97,10 @@ export default class ListGraph {
       if (d >= 1000) return d / 1000 + "s";
       return d;
     });
-    this.svg.attr(
-      "height",
-      (this.row.length + fixSpansSize + 1) * this.barHeight
-    );
+    this.svg.attr("height", (this.row.length + fixSpansSize + 1) * this.barHeight);
     this.svg
       .append("g")
       .attr("class", "trace-xaxis")
-
       .attr("transform", `translate(${this.width * 0.618 - 20},${30})`)
       .call(this.xAxis);
     this.sequentialScale = d3
@@ -111,10 +111,10 @@ export default class ListGraph {
     this.root.x0 = 0;
     this.root.y0 = 0;
   }
-  draw(callback: any) {
+  draw(callback: Function) {
     this.update(this.root, callback);
   }
-  click(d: any, scope: any) {
+  click(d: Recordable, scope: Recordable) {
     if (!d.data.type) return;
     if (d.children) {
       d._children = d.children;
@@ -125,17 +125,15 @@ export default class ListGraph {
     }
     scope.update(d);
   }
-  update(source: any, callback: any) {
+  update(source: Recordable, callback: Function) {
     const t = this;
     const nodes = this.root.descendants();
     let index = -1;
-    this.root.eachBefore((n: any) => {
+    this.root.eachBefore((n: Recordable) => {
       n.x = ++index * this.barHeight + 24;
       n.y = n.depth * 12;
     });
-    const node = this.svg
-      .selectAll(".trace-node")
-      .data(nodes, (d: any) => d.id || (d.id = ++this.i));
+    const node = this.svg.selectAll(".trace-node").data(nodes, (d: Recordable) => d.id || (d.id = ++this.i));
     const nodeEnter = node
       .enter()
       .append("g")
@@ -143,13 +141,13 @@ export default class ListGraph {
       .attr("class", "trace-node")
       .attr("style", "cursor: pointer")
       .style("opacity", 0)
-      .on("mouseover", function (event: any, d: Trace) {
+      .on("mouseover", function (event: MouseEvent, d: Trace) {
         t.tip.show(d, this);
       })
-      .on("mouseout", function (event: any, d: Trace) {
+      .on("mouseout", function (event: MouseEvent, d: Trace) {
         t.tip.hide(d, this);
       })
-      .on("click", (event: any, d: Trace) => {
+      .on("click", (event: MouseEvent, d: Trace) => {
         if (this.handleSelectSpan) {
           this.handleSelectSpan(d);
         }
@@ -163,32 +161,78 @@ export default class ListGraph {
       .attr("x", 20)
       .attr("width", "100%")
       .attr("fill", "rgba(0,0,0,0)");
+    nodeEnter
+      .append("image")
+      .attr("width", 16)
+      .attr("height", 16)
+      .attr("x", 6)
+      .attr("y", -10)
+      .attr("xlink:href", (d: any) =>
+        d.data.type === "Entry" ? icons.ENTRY : d.data.type === "Exit" ? icons.EXIT : "",
+      )
+      .style("display", (d: any) => {
+        ["Entry", "Exit"].includes(d.data.type) ? "inline" : "none";
+      })
+      .on("mouseover", function (event: any, d: Trace) {
+        event.stopPropagation();
+        t.prompt.show(d, this);
+      })
+      .on("mouseout", function (event: any, d: Trace) {
+        event.stopPropagation();
+        t.prompt.hide(d, this);
+      });
+    nodeEnter
+      .append("image")
+      .attr("width", 16)
+      .attr("height", 16)
+      .attr("x", 6)
+      .attr("y", -10)
+      .attr("xlink:href", (d: any) => {
+        const key = (d.data.refs || []).findIndex((d: { type: string }) => d.type === "CROSS_THREAD");
+        return key > -1 ? icons.STREAM : "";
+      })
+      .style("display", (d: any) => {
+        const key = (d.data.refs || []).findIndex((d: { type: string }) => d.type === "CROSS_THREAD");
+        return key > -1 ? "inline" : "none";
+      })
+      .on("mouseover", function (event: any, d: any) {
+        const a = {
+          ...d,
+          data: {
+            ...d.data,
+            type: "CROSS_THREAD",
+          },
+        };
+        event.stopPropagation();
+        t.prompt.show(a, this);
+      })
+      .on("mouseout", function (event: any, d: Trace) {
+        event.stopPropagation();
+        t.prompt.hide(d, this);
+      });
     nodeEnter
       .append("text")
       .attr("x", 13)
       .attr("y", 5)
       .attr("fill", "#E54C17")
-      .html((d: any) => (d.data.isError ? "◉" : ""));
+      .html((d: Recordable) => (d.data.isError ? "◉" : ""));
     nodeEnter
       .append("text")
       .attr("class", "node-text")
       .attr("x", 35)
       .attr("y", -6)
       .attr("fill", "#333")
-      .html((d: any) => {
+      .html((d: Recordable) => {
         if (d.data.label === "TRACE_ROOT") {
           return "";
         }
-        const label =
-          d.data.label.length > 30
-            ? `${d.data.label.slice(0, 30)}...`
-            : `${d.data.label}`;
+        const label = d.data.label.length > 30 ? `${d.data.label.slice(0, 30)}...` : `${d.data.label}`;
         return label;
       });
     nodeEnter
       .append("circle")
       .attr("r", 10)
-      .attr("cx", (d: any) => {
+      .attr("cx", (d: Recordable) => {
         const events = d.data.attachedEvents;
         if (events && events.length > 9) {
           return 272;
@@ -199,7 +243,7 @@ export default class ListGraph {
       .attr("cy", -5)
       .attr("fill", "none")
       .attr("stroke", "#e66")
-      .style("opacity", (d: any) => {
+      .style("opacity", (d: Recordable) => {
         const events = d.data.attachedEvents;
         if (events && events.length) {
           return 0.5;
@@ -213,7 +257,7 @@ export default class ListGraph {
       .attr("y", -1)
       .attr("fill", "#e66")
       .style("font-size", "10px")
-      .text((d: any) => {
+      .text((d: Recordable) => {
         const events = d.data.attachedEvents;
         if (events && events.length) {
           return `${events.length}`;
@@ -229,67 +273,58 @@ export default class ListGraph {
       .attr("fill", "#ccc")
       .style("font-size", "11px")
       .text(
-        (d: any) =>
+        (d: Recordable) =>
           `${d.data.layer || ""} ${
-            d.data.component ? "- " + d.data.component : d.data.component || ""
-          }`
+            d.data.component
+              ? "- " + d.data.component
+              : d.data.event
+              ? this.visDate(d.data.startTime) + ":" + d.data.startTimeNanos
+              : ""
+          }`,
       );
     nodeEnter
       .append("rect")
       .attr("rx", 2)
       .attr("ry", 2)
       .attr("height", 4)
-      .attr("width", (d: any) => {
+      .attr("width", (d: Recordable) => {
         if (!d.data.endTime || !d.data.startTime) return 0;
         return this.xScale(d.data.endTime - d.data.startTime) + 1 || 0;
       })
-      .attr("x", (d: any) =>
+      .attr("x", (d: Recordable) =>
         !d.data.endTime || !d.data.startTime
           ? 0
-          : this.width * 0.618 -
-              20 -
-              d.y +
-              this.xScale(d.data.startTime - this.min) || 0
+          : this.width * 0.618 - 20 - d.y + this.xScale(d.data.startTime - this.min) || 0,
       )
       .attr("y", -2)
-      .style(
-        "fill",
-        (d: any) =>
-          `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}`
-      );
+      .style("fill", (d: Recordable) => `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}`);
     nodeEnter
       .transition()
       .duration(400)
-      .attr("transform", (d: any) => `translate(${d.y + 5},${d.x})`)
+      .attr("transform", (d: Recordable) => `translate(${d.y + 5},${d.x})`)
       .style("opacity", 1);
     nodeEnter
       .append("circle")
       .attr("r", 3)
       .style("cursor", "pointer")
       .attr("stroke-width", 2.5)
-      .attr("fill", (d: any) =>
-        d._children
-          ? `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}`
-          : "rbga(0,0,0,0)"
+      .attr("fill", (d: Recordable) =>
+        d._children ? `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}` : "rbga(0,0,0,0)",
       )
-      .style("stroke", (d: any) =>
-        d.data.label === "TRACE_ROOT"
-          ? ""
-          : `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}`
+      .style("stroke", (d: Recordable) =>
+        d.data.label === "TRACE_ROOT" ? "" : `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}`,
       )
-      .on("click", (d: any) => {
+      .on("click", (d: Recordable) => {
         this.click(d, this);
       });
     node
       .transition()
       .duration(400)
-      .attr("transform", (d: any) => `translate(${d.y + 5},${d.x})`)
+      .attr("transform", (d: Recordable) => `translate(${d.y + 5},${d.x})`)
       .style("opacity", 1)
       .select("circle")
-      .attr("fill", (d: any) =>
-        d._children
-          ? `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}`
-          : ""
+      .attr("fill", (d: Recordable) =>
+        d._children ? `${this.sequentialScale(this.list.indexOf(d.data.serviceCode))}` : "",
       );
 
     // Transition exiting nodes to the parent's new position.
@@ -300,11 +335,9 @@ export default class ListGraph {
       .attr("transform", `translate(${source.y},${source.x})`)
       .style("opacity", 0)
       .remove();
-    const link = this.svg
-      .selectAll(".trace-link")
-      .data(this.root.links(), function (d: any) {
-        return d.target.id;
-      });
+    const link = this.svg.selectAll(".trace-link").data(this.root.links(), function (d: Recordable) {
+      return d.target.id;
+    });
 
     link
       .enter()
@@ -333,7 +366,7 @@ export default class ListGraph {
         return this.diagonal({ source: o, target: o });
       })
       .remove();
-    this.root.each(function (d: any) {
+    this.root.each(function (d: Recordable) {
       d.x0 = d.x;
       d.y0 = d.y;
     });
@@ -341,6 +374,9 @@ export default class ListGraph {
       callback();
     }
   }
+  visDate(date: number, pattern = "YYYY-MM-DD HH:mm:ss:SSS") {
+    return dayjs(date).format(pattern);
+  }
   resize() {
     if (!this.el) {
       return;
